@@ -17,7 +17,7 @@
  M(ji) = m(ji)/mu
  4 N(i)m(ji) = Theta(i)M(ji)
                                                                                                                
-/*-----------------------------------------------------------------
+*-----------------------------------------------------------------
   Bayesian and Maximum likelihood estimation of migration rates 
   using coalescent trees
  
@@ -49,7 +49,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 
-$Id: data.h 2071 2012-08-08 21:36:48Z beerli $
+$Id: data.h 2126 2013-01-09 03:33:51Z beerli $
  
 *----------------------------------------------------------------
 */
@@ -74,7 +74,7 @@ void init_data_structure1 (data_fmt ** data, option_fmt * options);
 void init_data_structure2 (data_fmt ** data, option_fmt * options,
                                long pop);
 void init_data_structure3 (data_fmt * data, option_fmt *options);
-void create_alleles (data_fmt * data, option_fmt * options);
+MYREAL create_alleles (data_fmt * data, option_fmt * options);
 void set_numind (data_fmt * data);
 
 long max_shuffled_individuals(option_fmt *options, data_fmt *data, long pop, long locus);
