@@ -33,7 +33,7 @@
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- $Id: mcmc1.c 2158 2013-04-29 01:56:20Z beerli $
+ $Id: mcmc1.c 2169 2013-08-24 19:02:04Z beerli $
  -------------------------------------------------------*/
 /* \file mcmc1.c
  
@@ -1947,7 +1947,7 @@ prob_tree (world_fmt * world, timelist_fmt * tyme)
     boolean usem = world->options->usem;
     MYREAL pk;
     const MYREAL mu_rate = world->options->mu_rates[world->locus];
-    const MYREAL lmu_rate = world->options->lmu_rates[world->locus];
+    //const MYREAL lmu_rate = world->options->lmu_rates[world->locus];
     tyme->tl[0].interval = tyme->tl[0].age;
     for (j = 1; j < tyme->T; j++)
     {
