@@ -36,7 +36,7 @@
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
- $Id: migration.h 2157 2013-04-16 22:27:40Z beerli $
+ $Id: migration.h 2165 2013-08-24 16:33:45Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -552,8 +552,8 @@ typedef struct _option
     MYREAL freqt;
     /* random number options */
     short autoseed;
-    long inseed;
-    long saveseed;
+    unsigned long inseed;
+    unsigned long saveseed;
     /* mcmc options */
     boolean bayes_infer;
   boolean integrated_like;
@@ -629,7 +629,7 @@ typedef struct _option
   long mutationrate_year_numalloc; // 
   MYREAL generation_year;
   long randomsubset;
-  long randomsubsetseed;
+  unsigned long randomsubsetseed;
 #ifdef SEASON
   MYREAL *timings; // vector of time points (options)
   long numtimings; // number of elements in the timings vector
